@@ -36,9 +36,9 @@ class Pound(object):
         self.options = options
         self.buildout = buildout
         self.outputdir = os.path.join(self.buildout['buildout']['parts-directory'], self.name)
-        self.pidfile = os.path.join(self.buildout['buildout']['var-directory'], "%s.pid" % self.name)
+        self.pidfile = os.path.join(self.buildout['buildout']['directory'], "var", "%s.pid" % self.name)
         self.cfgfile = os.path.join(self.outputdir, "pound.cfg")
-        self.options.setdefault('control', os.path.join(self.buildout['buildout']['var-directory'], "%s.ctl" % self.name))
+        self.options.setdefault('control', os.path.join(self.buildout['buildout']['directory'], "var", "%s.ctl" % self.name))
         self.options.setdefault('executable', '/usr/sbin/pound')
         self.options.setdefault('user', 'www-data')
         self.options.setdefault('group', 'www-data')
